# Model training from scratch

<h2>Table of contents</h2>

[[toc]]

## 1. Tokenization and input features

## 2. Model encoder

## 3. Task head

## 4. Training data preparation

## 5. Model training, ouput and metrics

## 6. Next steps








